@@ -10,6 +10,16 @@ ACCOUNT_BASE_URL = 'https://account.app.net'
 
 
 def find_method(key, vars=None):
+    """ Given a method key, returns a tuple containing the HTTP verb and the
+    full API endpoint for that particular method. If any vars are passed in,
+    they are substituted out in the URL with the values provided.
+
+    :param key: the API method key
+    :param dict vars: (optional) a dict containing any variables to substitute
+        out in the endpoint URI
+    :returns: (tuple) HTTP verb and full API endpoint URL
+
+    """
     if key not in method_map:
         raise MethodNotFoundException
 
